@@ -51,7 +51,7 @@ class _ColorFormatter(logging.Formatter):
             record.levelname = levelname_color
         return logging.Formatter.format(self, record)
 
-if platform.system().upper() in ['WINDOWS']:
+if platform.system().upper() not in ['WINDOWS']:
     ColorFormatter = _ColorFormatter
 else:
     ColorFormatter = logging.Formatter
