@@ -380,7 +380,7 @@ class JSONRPCService(DictMixin, object):
         if not req.method == "POST":
             self._logger.debug("request method '%s' not accepted." % req.method)
             resp = Response(JSONRPCBuilder.response(error = JSONRPCInvalidRequestError()),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         post_data = req.body.strip()
         try:
@@ -388,7 +388,7 @@ class JSONRPCService(DictMixin, object):
         except:
             self._logger.debug("post data invalid: %r" % post_data, exc_info = True)
             resp = Response(JSONRPCBuilder.response(error = JSONRPCParseError()),
-                            content_type = "%s" % JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         if 'version' in jsonrpc_data:
             version = jsonrpc_data['version']
@@ -397,12 +397,12 @@ class JSONRPCService(DictMixin, object):
         else:
             self._logger.debug("the 'version' or 'jsonrpc' field missing." % post_data, exc_info = True)
             resp = Response(JSONRPCBuilder.response(error = JSONRPCParseError()),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         if "method" not in jsonrpc_data:
             self._logger.debug("`method` field not found.")
             resp = Response(JSONRPCBuilder.response(error = JSONRPCParseError(), version = version),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         args = []
         kargs = {}
@@ -423,7 +423,7 @@ class JSONRPCService(DictMixin, object):
         if provider is None:
             self._logger.debug("method '%s' not found." % jsonrpc_data["method"])
             resp = Response(JSONRPCBuilder.response(error = JSONRPCMethodNotFoundError(), version = version),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         
         environ["khan.web.service"] = self
@@ -433,7 +433,7 @@ class JSONRPCService(DictMixin, object):
         try:
             result = provider(*args, **kargs)
             resp = Response(JSONRPCBuilder.response(result = result, id = jsonrpc_data["id"], version = version),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         except HTTPException, httpe:
             self._logger.debug("`%r` raised HTTPException: %s (code: %s)",
@@ -447,18 +447,18 @@ class JSONRPCService(DictMixin, object):
             self._logger.error("calling `%r` with invalid arguments." % self.get_provider_name(provider), exc_info = True)
             resp = Response(JSONRPCBuilder.response(error = JSONRPCInvalidParamsError(), 
                                                     id = jsonrpc_data["id"], version = version),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         except JSONRPCError, e:
             self._logger.error("jsonrpc error.", exc_info = True)
             resp = Response(JSONRPCBuilder.response(error = e, id = jsonrpc_data["id"], version = version),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
         except:
             self._logger.error("`%r` raised unknown exception." % self.get_provider_name(provider), exc_info = True)
             resp = Response(JSONRPCBuilder.response(error = JSONRPCInternalError(), 
                                                     id = jsonrpc_data["id"], version = version),
-                            content_type = JSON_MIME_TYPE)
+                            content_type = JSON_MIME_TYPE, charset = 'utf-8')
             return resp(environ, start_response)
 
     def __call__(self, environ, start_response):
@@ -845,3 +845,4 @@ class JSONRPCClientCommand(Command):
             print result
             return EX_OK
 
+
